import base64
from flask import jsonify, make_response
from app import db
from app.utils import create_thumbnail
def serialize_customer(customer):
    if customer.logo:
        logo_binary = base64.b64decode(customer.logo)
        logo_base64 = base64.b64encode(logo_binary).decode()
    else:
        logo_base64 = None
    return {
        'id': customer.customer_id,
        'customer_name': customer.customer_name,
        'email': customer.email,
        'description': customer.description,
        'address': customer.address,
        'logo': logo_base64,
        'logo_content_type': customer.logo_content_type,
        'status': customer.status,
    }
def process_image(request_files):
    image_data = ""
    logo_content_type = ""
    if 'image' in request_files:
        image_file, logo_content_type = create_thumbnail(request_files['image'])
        if image_file:
            image_data = base64.b64encode(image_file.read()).decode('utf-8')
    return image_data, logo_content_type
def handle_db_commit(data, operation_type='operation'):
    operation_messages = {
        'create': 'Organisation created successfully',
        'update': 'Organisation updated successfully',
        'delete': 'Organisation deleted successfully'
    }
    try:
        if operation_type == 'create':
            db.session.add(data)
        elif operation_type == 'delete':
            db.session.delete(data)
        db.session.commit()
        message = operation_messages.get(operation_type, 'Operation successful')
        return make_response(jsonify({'message': message, "status": "Success"}), 200)
    except Exception as e:
        db.session.rollback()
        return make_response(jsonify({'message': str(e), "status": "error"}), 500)
def paginate_query(query, page, per_page):
    paginated = query.paginate(page=page, per_page=per_page, error_out=False)
    data = {
        'total_count': paginated.total,
        'total_pages': paginated.pages,
        'start_index': (page - 1) * per_page + 1,
        'end_index': min(page * per_page, paginated.total),
        'page': page,
        'per_page': per_page
    }
    return paginated.items, data